@@ -78,7 +78,7 @@ def define_auto(code):
             m = 'public ItemStack '+var_name+" = new ItemStack();\n"
         elif code.__contains__('getName') or code.__contains__('toString'):
             type_Var = "String"
-            m = 'public String '+var_name+"= new String();\n"
+            m = 'public String '+var_name+";\n"
         elif code.__contains__('getInventory'):
             type_Var = "Inventory"
             m = 'public Inventory '+var_name+";\n"
@@ -1136,7 +1136,7 @@ def make(server,**setting):
     last_String = 'package Main;\n\n'+addition+javacode
     files.write(last_String)
     files.close()
-    minepy = "minepy"
+    minepy = "python minepy.py"
     if server == True:
         minepy += " -s"
     if port == True:
